Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: runtime/vm/flow_graph.h

Issue 2751103003: VM: Propagate non-nullness from instance calls. (Closed)
Patch Set: canonicalize redundant redefinitions Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/flow_graph.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph.h
diff --git a/runtime/vm/flow_graph.h b/runtime/vm/flow_graph.h
index 549a8bafc6dfa29b52b3d3a05bdfae5f8f3ddb2a..63a6037fa1aac4458e17f2d9b2980877f038c655 100644
--- a/runtime/vm/flow_graph.h
+++ b/runtime/vm/flow_graph.h
@@ -210,11 +210,11 @@ class FlowGraph : public ZoneAllocated {
void ComputeBlockEffects();
BlockEffects* block_effects() const { return block_effects_; }
// Insert a redefinition of an original definition at the beginning of a
// basic block and rename all dominated uses of the original.
// If an equivalent redefinition is already present, nothing is inserted.
// Returns the redefintion, if a redefinition was inserted, NULL otherwise.
- RedefinitionInstr* EnsureRedefinition(BlockEntryInstr* block,
+ RedefinitionInstr* EnsureRedefinition(Instruction* prev,
Definition* original,
CompileType compile_type);
« no previous file with comments | « no previous file | runtime/vm/flow_graph.cc » ('j') | no next file with comments »
@@ -210,11 +210,11 @@ class FlowGraph : public ZoneAllocated {
void ComputeBlockEffects();
BlockEffects* block_effects() const { return block_effects_; }
- // Insert a redefinition of an original definition at the beginning of a
- // basic block and rename all dominated uses of the original.
- // If an equivalent redefinition is already present, nothing is inserted.
+ // Insert a redefinition of an original definition after prev and rename all
+ // dominated uses of the original. If an equivalent redefinition is already
+ // present, nothing is inserted.
// Returns the redefintion, if a redefinition was inserted, NULL otherwise.

Powered by Google App Engine
This is Rietveld 408576698